@@ -759,32 +759,42 @@ class WordToken(models.Model):
             return foll[0]
         return None
 
-    def getPreviousContext(self,window=10):
+    def getPreviousContext(self,window='auto'):
+        if window == 'auto':
+            window_max = 10
+        else:
+            window_max = window
         context = []
         prev = self.getPreviousWord()
         durSum = prev.getDuration()
-        while durSum <= window:
+        while durSum <= window_max:
             if prev is None:
                 break
             if prev.WordType.isWord():
                 context.append(prev)
             durSum += prev.getDuration()
+            if prev.afterPause():
+                break
             prev = prev.getPreviousWord()
         return reversed(context)
 
-    def getFollowingContext(self,window=10):
+    def getFollowingContext(self,window='auto'):
+        if window == 'auto':
+            window_max = 10
+        else:
+            window_max = window
         context = []
         foll = self.getFollowingWord()
         durSum = foll.getDuration()
-        while durSum <= window:
+        while durSum <= window_max:
             if foll is None:
                 break
             if foll.WordType.isWord():
                 context.append(foll)
-            foll = foll.getFollowingWord()
-            if foll is None:
-                break
             durSum += foll.getDuration()
+            if foll.beforePause():
+                break
+            foll = foll.getFollowingWord()
         return context
 
     def getRecentRepetition(self):
@@ -887,33 +897,19 @@ class WordToken(models.Model):
     def getPreviousSpeakingRate(self):
         if self.afterPause():
             return 0.0
-        prevInd = self.getPreviousWord()
-        pauseFound = False
-        secsToPause = 0.0
-        sylsToPause = 0
-        while not pauseFound:
-            if prevInd.afterPause():
-                pauseFound = True
-            secsToPause += prevInd.getDuration()
-            sylsToPause += prevInd.getNumSylls()
-            prevInd = prevInd.getPreviousWord()
-        rate = float(sylsToPause)/float(secsToPause)
+        prev_context = self.getPreviousContext()
+        total_syllables = float(sum([x.getNumSylls() for x in prev_context]))
+        total_seconds = float(sum([x.getDuration() for x in prev_context]))
+        rate = total_syllables / total_seconds
         return rate
 
     def getFollowingSpeakingRate(self):
         if self.beforePause():
             return 0.0
-        follInd = self.getFollowingWord()
-        pauseFound = False
-        secsToPause = 0.0
-        sylsToPause = 0
-        while not pauseFound:
-            if follInd.beforePause():
-                pauseFound = True
-            secsToPause += follInd.getDuration()
-            sylsToPause += follInd.getNumSylls()
-            follInd = follInd.getFollowingWord()
-        rate = float(sylsToPause)/float(secsToPause)
+        foll_context = self.getFollowingContext()
+        total_syllables = float(sum([x.getNumSylls() for x in foll_context]))
+        total_seconds = float(sum([x.getDuration() for x in foll_context]))
+        rate = total_syllables / total_seconds
         return rate
 
     def getPreviousCondProb(self):
@@ -978,9 +974,10 @@ class WordToken(models.Model):
 
     def getAnalysisLines(self,form):
         if self.Output is not None:
-            outline = copy.copy(self.Output)
+            outline = {x: self.Output[x] for x in self.Output if x not in form['force_fetch']}
         else:
             outline = {}
+
         wanted_fields =[]
         if outline == {}:
             outline['Word'] = self.WordType.Label
